package com.diagbot.web;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.User;
import com.diagbot.exception.CommonException;
import com.diagbot.exception.ErrorCode;
import com.diagbot.facade.UserFacade;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * @Description: 用户对外接口层
 * @author: gaodm
 * @time: 2018/8/2 13:56
 */
@RestController
@RequestMapping("/user")
public class UserController {

    @Autowired
    private UserFacade userFacade;

    @ApiOperation(value = "注册", notes = "username和password为必选项")
    @PostMapping("/registry")
    @SysLogger("registry")
    @Transactional
    public RespDTO createUser(@RequestBody User user){
        //参数判读省略,判读该用户在数据库是否已经存在省略
        userFacade.createUser(user);
//        throw new CommonException(ErrorCode.FAIL);
        return RespDTO.onSuc(user);
    }

    @ApiOperation(value = "登录", notes = "username和password为必选项")
    @PostMapping("/login")
    @SysLogger("login")
    public RespDTO login(@RequestParam String username , @RequestParam String password){
        //参数判读省略
      return   userFacade.login(username,password);
    }

    @ApiOperation(value = "根据用户名获取用户", notes = "根据用户名获取用户")
    @PostMapping("/{username}")
    @PreAuthorize("hasRole('USER')")
    @SysLogger("getUserInfo")
//    @PreAuthorize("hasAnyAuthority('ROLE_USER')")
    public RespDTO getUserInfo(@PathVariable("username") String username){
        //参数判读省略
        User user=  userFacade.getUserInfo(username);
        return RespDTO.onSuc(user);
    }

    @ApiOperation(value = "根据用户id获取用户信息", notes = "根据用户id获取用户信息")
    @PostMapping("/getById")
    @PreAuthorize("hasRole('USER')")
//    @SysLogger("getUserInfoByID")
    //    @PreAuthorize("hasAnyAuthority('ROLE_USER')")
    public RespDTO getUserInfoByID(Long id, Page page){
        //参数判读省略
        Page<Map> mapPage = new Page<>(page.getCurrent(),page.getSize());
        User userVo = new User();
        userVo.setId(id);
        Page<User> user=  userFacade.selectUserListPage(mapPage, userVo);
        return RespDTO.onSuc(user);
    }

    @ApiOperation(value = "注册事务", notes = "username和password为必选项")
    @PostMapping("/registryTran")
    @SysLogger("registryTran")
    @Transactional
    public RespDTO createUserTran(@RequestBody User user){
        //参数判读省略,判读该用户在数据库是否已经存在省略
        userFacade.createUser(user);
        throw new CommonException(ErrorCode.FAIL);
//        return RespDTO.onSuc(user);
    }

//    @Autowired
//    private AmqpTemplate rabbitTemplate;
//    @GetMapping("/test")
//    public void test(){
//        rabbitTemplate.convertAndSend(RabbitConfig.queueName, "Hello from RabbitMQ!");
//    }
}
